=========
Executors
=========

Executors are providing the way an incoming message will be dispatched so that
the message can be used for meaningful work. Different types of executors are
supported, each with its own set of restrictions and capabilities.

Available Executors
===================

.. list-plugins:: oslo.messaging.executors
   :detailed:
